@@ -237,9 +237,7 @@ class Simulator:
 
             if source_circuit.is_mixed_state or self._noise_model:
                 # Only DensityMatrixSimulator handles noise well, can use Simulator but it is slower
-                # ignore_measurement_results changes measurement gates to Krauss operators so simulators
-                # can be called once and density matrix sampled repeatedly.
-                cirq_simulator = cirq.DensityMatrixSimulator(dtype=np.complex128, ignore_measurement_results=True)
+                cirq_simulator = cirq.DensityMatrixSimulator(dtype=np.complex128)
             else:
                 cirq_simulator = cirq.Simulator(dtype=np.complex128)
 
@@ -248,6 +246,9 @@ class Simulator:
 
             # Calculate final density matrix and sample from that for noisy simulation or simulating mixed states
             if self._noise_model or source_circuit.is_mixed_state:
+                # cirq.dephase_measurements changes measurement gates to Krauss operators so simulators
+                # can be called once and density matrix sampled repeatedly.
+                translated_circuit = cirq.dephase_measurements(translated_circuit)
                 sim = cirq_simulator.simulate(translated_circuit, initial_state=cirq_initial_statevector)
                 self._current_state = sim.final_density_matrix
                 indices = list(range(source_circuit.width))
